Class: Fastlane::Actions::IosUpdateMetadataSourceAction

Inherits:
Action
  • Object
show all
Defined in:
lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb

Documentation collapse

Class Method Summary collapse

Class Method Details

.authorsObject



60
61
62
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 60

def self.authors
  ['Automattic']
end

.available_optionsObject



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 29

def self.available_options
  [
    FastlaneCore::ConfigItem.new(key: :po_file_path,
                                 env_name: 'FL_IOS_UPDATE_METADATA_SOURCE_PO_FILE_PATH',
                                 description: 'The path of the .po file to generate',
                                 type: String,
                                 verify_block: proc do |value|
                                                 UI.user_error!("No .po file path for UpdateMetadataSourceAction given, pass using `po_file_path: 'file path'`") unless value && !value.empty?
                                               end),
    FastlaneCore::ConfigItem.new(key: :release_version,
                                 env_name: 'FL_IOS_UPDATE_METADATA_SOURCE_RELEASE_VERSION',
                                 description: 'The release version of the app (to use to mark the release notes)',
                                 verify_block: proc do |value|
                                                 UI.user_error!("No relase version for UpdateMetadataSourceAction given, pass using `release_version: 'version'`") unless value && !value.empty?
                                               end),
    FastlaneCore::ConfigItem.new(key: :source_files,
                                 env_name: 'FL_IOS_UPDATE_METADATA_SOURCE_SOURCE_FILES',
                                 description: 'The hash with the path to the source files and the key to use to include their content',
                                 type: Hash,
                                 verify_block: proc do |value|
                                                 UI.user_error!("No source file hash for UpdateMetadataSourceAction given, pass using `source_files: 'source file hash'`") unless value && !value.empty?
                                               end),
  ]
end

.deprecated?Boolean

Returns:

  • (Boolean)


68
69
70
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 68

def self.deprecated?
  true
end

.descriptionObject



21
22
23
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 21

def self.description
  'Updates the AppStoreStrings.po file with the data from text source files'
end

.detailsObject



25
26
27
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 25

def self.details
  'Updates the AppStoreStrings.po file with the data from text source files'
end

.is_supported?(platform) ⇒ Boolean

Returns:

  • (Boolean)


64
65
66
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 64

def self.is_supported?(platform)
  %i[ios mac].include?(platform)
end

.outputObject



54
55
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 54

def self.output
end

.return_valueObject



57
58
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 57

def self.return_value
end

.run(params) ⇒ Object



6
7
8
9
10
11
12
13
14
15
# File 'lib/fastlane/plugin/wpmreleasetoolkit/actions/ios/ios_update_metadata_source.rb', line 6

def self.run(params)
  UI.deprecated('`ios_update_metadata_source` is deprecated. Please use `gp_update_metadata_source` with `commit_changes: true` instead.')

  other_action.(
    po_file_path: params[:po_file_path],
    source_files: params[:source_files],
    release_version: params[:release_version],
    commit_changes: true
  )
end